require "constants"
require "Ball"
require "Paddle"
require "Player"

local screen_w, screen_h = constants.screen_w, constants.screen_h


Game = class {}

Game[class.init] = function (self)
	-- Setup players
	self.player1 = Player(screen_w * 0.25, screen_h/8)
	self.player1.paddle = Paddle(self.player1)
	self.player2 = Player(screen_w * 0.75, screen_h/8)
	self.player2.paddle = Paddle(self.player2, true)
	self.ball = Ball(self)

	local paddle1, paddle2, ball = self.player1.paddle, self.player2.paddle, self.ball

	ball:reset()

	-- Keyboard map
	local counter = 0
	self.keymap = {
		['w']		= function () paddle1:up() end,
		['s']		= function () paddle1:dn() end,
		['up']		= function () paddle2:up() end,
		['down']	= function () paddle2:dn() end,
		[' ']		= function ()
			ball:launch(counter % 2 < 1 and 2 or -2, counter % 4 < 2 and 1 or -1)
			counter = counter + 1
		end
	}
end

function Game:getPaddle(side)
	return self[(side == 'l' and 'player1') or (side == 'r' and 'player2')].paddle
end


local pairs, ipairs = pairs, ipairs

function Game:update(dt)
	for k, v in pairs(self.keymap) do
		if love.keyboard.isDown(k) then v() end
	end
	self.player1.paddle:update(dt)
	self.player2.paddle:update(dt)
	self.ball:update(dt)
end


function Game:draw()
	self.player1:draw()
	self.player2:draw()
	self.player1.paddle:draw()
	self.player2.paddle:draw()
	self.ball:draw()
end


return Game


-- vim: ts=4 sw=4 si
