Menu = class {}

local x, y, h = 300, 100, 32
local focus_meta = { __mode = 'k' }

local font

Menu[class.init] = function (self, menu)
	self.stack = {}
	self.focus = {}
	setmetatable(self.focus, focus_meta)

	if menu then
		self.focus[menu] = 1
		self.active = menu
	end
	
	font = font or love.graphics.newFont(24)
end


local function up (self)
	local menu = self.active
	self.focus[menu] = self.focus[menu] <= 1 and #menu or self.focus[menu] - 1
end

local function dn (self)
	local menu = self.active
	self.focus[menu] = self.focus[menu] >= #menu and 1 or self.focus[menu] + 1
end

local function enter (self)
	local menu = self.active
	local o = menu[self.focus[menu]][2]
	if type(o) == "function" then
		o()
	elseif type(o) == "table" then
		self:load(o)
	end
end

local function back (self)
	if #self.stack > 0 then
		self.active = nil
		self:load(table.remove(self.stack))
	elseif self.active.escape then
		self.active.escape()
	end
end

local color = { 127, 127, 127 }
local color_focus = { 255, 255, 255 }
local function draw_item(item, x, y, focused)
	love.graphics.setFont(font)
	love.graphics.setColor(unpack(focused and color_focus or color))
	love.graphics.printf(item[1], x, y, 200, "center")
end

local function draw (self)
	local menu = self.active
	for i, v in ipairs(menu) do
		draw_item(v, x, y + (i - 1) * h, self.focus[menu] == i)
	end
end

local keymap = {
	["up"]		= up,
	["down"]	= dn,
	["return"]	= enter,
	["escape"]	= back
}

function Menu:load (menu)
	if self.active then
		table.insert(self.stack, self.active)
	end
	if not self.focus[menu] then self.focus[menu] = 1 end
	self.active = menu
end

function Menu:activate ()
	love.update = nil

	function love.draw () draw(self) end

	function love.keypressed (key)
		if keymap[key] then
			keymap[key](self)
		end
	end
end


return Menu


-- vim: ts=4 sw=4 si
