Paddle = class {
	vy = 0,
	thrust = 0,
}

local width, length = constants.paddle_w, constants.paddle_l
local bounce = 0.25
local accel = 2^12.5
local brake_strength = 2^12
local max_speed = 2^12

local screen_w, screen_h = constants.screen_w, constants.screen_h
local min_y, max_y = length/2, screen_h - length/2

Paddle[class.init] = function (self, player, right_side)
	self.x = right_side and screen_w - width/2 or width/2
	self.y = screen_h/2
	self.player = player
end


function Paddle:up ()
	self.thrust = self.thrust - 1
end

function Paddle:dn ()
	self.thrust = self.thrust + 1
end

function Paddle:update (dt)
	-- Velocity phase
	local thrust, brake = self.thrust, true

	if thrust ~= 0 then
		local current_vel = thrust > 0 and self.vy or -self.vy
		if current_vel < max_speed then
			self.vy = self.vy + dt * (thrust > 0 and accel or -accel)
			if current_vel >= 0 then brake = false end
		end
		self.thrust = 0
	end

	if brake then
		self.vy = self.vy * (brake_strength + 1) ^ -dt
	end

	-- Position phase
	self.y = self.y + self.vy * dt

	-- Collision resolution
	local y = self.y
	local ext = (y < min_y and min_y) or (y > max_y and max_y)
	if ext then
		self.y = ext + (ext - y) * bounce
		self.vy = self.vy * -bounce
	end
end

function Paddle:draw ()
	love.graphics.setColor(255, 255, 255)
	love.graphics.rectangle("fill", self.x - width/2, self.y - length/2, width, length)
end


return Paddle


-- vim: ts=4 sw=4 si
