require "class"
require "Menu"
require "Game"

function love.run ()
	-- Prepare stuff
	love.load(arg)

	-- Set a reasonable FPS limit
    local FPS = 60
    local dt = 1 / FPS

	-- Timekeeping variables
	local time

	-- Main loop
	while true do

		-- Update the time
		time = love.timer.getTime()

		-- Process events
		for e, a, b, c in love.event.poll() do
			if e == "q" then
				if love.quit then love.quit() end
				if love.audio then love.audio.stop() end
				return
			end
			love.handlers[e](a, b, c)
		end
		
		-- Do the game mechanic
		if love.update then love.update(dt) end

		-- Draw the graphics
		love.graphics.clear()
		love.draw()

		-- Wait for the end of this frame
		local time_work = love.timer.getTime() - time
		if time_work < dt then
			local time_wait = dt - time_work
			love.timer.sleep(time_wait * 1000)
		end

		-- Show the frame
		love.graphics.present()
	end
end

local function resume_game ()
	function love.update (dt)
		game:update(dt)
	end
	function love.draw () game:draw() end
	function love.keypressed (key)
		if key == "escape" then
			game_menu:activate()
		end
	end
end

local function start_game ()
	game = Game()
	resume_game()
end

local function end_game ()
	game = nil
	main_menu:activate()
end

local function quit ()
	love.event.push("q")
end

function love.load ()
	love.graphics.setBackgroundColor(0, 0, 0)

	game_menu = Menu {
		{ "Resume", resume_game },
		{ "End Game", end_game },
		{ "Quit", quit },
		escape = resume_game
	}
	main_menu = Menu {
		{ "Start Game", start_game },
		{ "Quit", quit }
	}

	main_menu:activate()
end


-- vim: ts=4 sw=4 si
